/* tslint:disable */
/* eslint-disable */
/**
* Read a Parquet file into Arrow data using the [`arrow`](https://crates.io/crates/arrow) and
* [`parquet`](https://crates.io/crates/parquet) Rust crates.
*
* This returns an Arrow table in WebAssembly memory. To transfer the Arrow table to JavaScript
* memory you have two options:
*
* - (Easier): Call {@linkcode Table.intoIPCStream} to construct a buffer that can be parsed with
*   Arrow JS's `tableFromIPC` function.
* - (More performant but bleeding edge): Call {@linkcode Table.intoFFI} to construct a data
*   representation that can be parsed zero-copy from WebAssembly with
*   [arrow-js-ffi](https://github.com/kylebarron/arrow-js-ffi).
*
* Example:
*
* ```js
* import { tableFromIPC } from "apache-arrow";
* // Edit the `parquet-wasm` import as necessary
* import { readParquet } from "parquet-wasm/node/arrow1";
*
* const resp = await fetch("https://example.com/file.parquet");
* const parquetUint8Array = new Uint8Array(await resp.arrayBuffer());
* const arrowWasmTable = readParquet(parquetUint8Array);
* const arrowTable = tableFromIPC(arrowWasmTable.intoIPCStream());
* ```
*
* @param parquet_file Uint8Array containing Parquet data
* @param {Uint8Array} parquet_file
* @returns {Table}
*/
export function readParquet(parquet_file: Uint8Array): Table;
/**
* Write Arrow data to a Parquet file using the [`arrow`](https://crates.io/crates/arrow) and
* [`parquet`](https://crates.io/crates/parquet) Rust crates.
*
* For example, to create a Parquet file with Snappy compression:
*
* ```js
* import { tableToIPC } from "apache-arrow";
* // Edit the `parquet-wasm` import as necessary
* import {
*   Table,
*   WriterPropertiesBuilder,
*   Compression,
*   writeParquet,
* } from "parquet-wasm/node/arrow1";
*
* // Given an existing arrow JS table under `table`
* const wasmTable = Table.fromIPCStream(tableToIPC(table, "stream"));
* const writerProperties = new WriterPropertiesBuilder()
*   .setCompression(Compression.SNAPPY)
*   .build();
* const parquetUint8Array = writeParquet(wasmTable, writerProperties);
* ```
*
* If `writerProperties` is not provided or is `null`, the default writer properties will be used.
* This is equivalent to `new WriterPropertiesBuilder().build()`.
*
* @param table A {@linkcode Table} representation in WebAssembly memory.
* @param writer_properties (optional) Configuration for writing to Parquet. Use the {@linkcode
* WriterPropertiesBuilder} to build a writing configuration, then call `.build()` to create an
* immutable writer properties to pass in here.
* @returns Uint8Array containing written Parquet data.
* @param {Table} table
* @param {WriterProperties | undefined} [writer_properties]
* @returns {Uint8Array}
*/
export function writeParquet(table: Table, writer_properties?: WriterProperties): Uint8Array;
/**
* @param {string} url
* @param {number | undefined} [content_length]
* @returns {Promise<ReadableStream>}
*/
export function readParquetStream(url: string, content_length?: number): Promise<ReadableStream>;
/**
* Returns a handle to this wasm instance's `WebAssembly.Memory`
* @returns {Memory}
*/
export function wasmMemory(): Memory;
/**
* Returns a handle to this wasm instance's `WebAssembly.Table` which is the indirect function
* table used by Rust
* @returns {FunctionTable}
*/
export function _functionTable(): FunctionTable;
/**
*/
export enum TimeUnit {
  Second = 0,
  Millisecond = 1,
  Microsecond = 2,
  Nanosecond = 3,
}
/**
*/
export enum IntervalUnit {
  YearMonth = 0,
  DayTime = 1,
  MonthDayNano = 2,
}
/**
*/
export enum Precision {
  Half = 0,
  Single = 1,
  Double = 2,
}
/**
* The Parquet version to use when writing
*/
export enum WriterVersion {
  V1 = 0,
  V2 = 1,
}
/**
*/
export enum Type {
/**
* The default placeholder type
*/
  NONE = 0,
/**
* A NULL type having no physical storage
*/
  Null = 1,
/**
* Signed or unsigned 8, 16, 32, or 64-bit little-endian integer
*/
  Int = 2,
/**
* 2, 4, or 8-byte floating point value
*/
  Float = 3,
/**
* Variable-length bytes (no guarantee of UTF8-ness)
*/
  Binary = 4,
/**
* UTF8 variable-length string as List<Char>
*/
  Utf8 = 5,
/**
* Boolean as 1 bit, LSB bit-packed ordering
*/
  Bool = 6,
/**
* Precision-and-scale-based decimal type. Storage type depends on the parameters.
*/
  Decimal = 7,
/**
* int32_t days or int64_t milliseconds since the UNIX epoch
*/
  Date = 8,
/**
* Time as signed 32 or 64-bit integer, representing either seconds, milliseconds,
* microseconds, or nanoseconds since midnight since midnight
*/
  Time = 9,
/**
* Exact timestamp encoded with int64 since UNIX epoch (Default unit millisecond)
*/
  Timestamp = 10,
/**
* YEAR_MONTH or DAY_TIME interval in SQL style
*/
  Interval = 11,
/**
* A list of some logical data type
*/
  List = 12,
/**
* Struct of logical types
*/
  Struct = 13,
/**
* Union of logical types
*/
  Union = 14,
/**
* Fixed-size binary. Each value occupies the same number of bytes
*/
  FixedSizeBinary = 15,
/**
* Fixed-size list. Each value occupies the same number of bytes
*/
  FixedSizeList = 16,
/**
* Map of named logical types
*/
  Map = 17,
/**
* Measure of elapsed time in either seconds, milliseconds, microseconds or nanoseconds.
*/
  Duration = 18,
}
/**
* Encodings supported by Parquet.
* Not all encodings are valid for all types. These enums are also used to specify the
* encoding of definition and repetition levels.
*/
export enum Encoding {
/**
* Default byte encoding.
* - BOOLEAN - 1 bit per value, 0 is false; 1 is true.
* - INT32 - 4 bytes per value, stored as little-endian.
* - INT64 - 8 bytes per value, stored as little-endian.
* - FLOAT - 4 bytes per value, stored as little-endian.
* - DOUBLE - 8 bytes per value, stored as little-endian.
* - BYTE_ARRAY - 4 byte length stored as little endian, followed by bytes.
* - FIXED_LEN_BYTE_ARRAY - just the bytes are stored.
*/
  PLAIN = 0,
/**
* **Deprecated** dictionary encoding.
*
* The values in the dictionary are encoded using PLAIN encoding.
* Since it is deprecated, RLE_DICTIONARY encoding is used for a data page, and
* PLAIN encoding is used for dictionary page.
*/
  PLAIN_DICTIONARY = 1,
/**
* Group packed run length encoding.
*
* Usable for definition/repetition levels encoding and boolean values.
*/
  RLE = 2,
/**
* Bit packed encoding.
*
* This can only be used if the data has a known max width.
* Usable for definition/repetition levels encoding.
*/
  BIT_PACKED = 3,
/**
* Delta encoding for integers, either INT32 or INT64.
*
* Works best on sorted data.
*/
  DELTA_BINARY_PACKED = 4,
/**
* Encoding for byte arrays to separate the length values and the data.
*
* The lengths are encoded using DELTA_BINARY_PACKED encoding.
*/
  DELTA_LENGTH_BYTE_ARRAY = 5,
/**
* Incremental encoding for byte arrays.
*
* Prefix lengths are encoded using DELTA_BINARY_PACKED encoding.
* Suffixes are stored using DELTA_LENGTH_BYTE_ARRAY encoding.
*/
  DELTA_BYTE_ARRAY = 6,
/**
* Dictionary encoding.
*
* The ids are encoded using the RLE encoding.
*/
  RLE_DICTIONARY = 7,
/**
* Encoding for floating-point data.
*
* K byte-streams are created where K is the size in bytes of the data type.
* The individual bytes of an FP value are scattered to the corresponding stream and
* the streams are concatenated.
* This itself does not reduce the size of the data but can lead to better compression
* afterwards.
*/
  BYTE_STREAM_SPLIT = 8,
}
/**
*/
export enum BufferType {
/**
*
*     * used in List type, Dense Union and variable length primitive types (String, Binary)
*     
*/
  Offset = 0,
/**
*
*     * actual data, either fixed width primitive types in slots or variable width delimited by an OFFSET vector
*     
*/
  Data = 1,
/**
*
*     * Bit vector indicating if each value is null
*     
*/
  Validity = 2,
/**
*
*     * Type vector used in Union type
*     
*/
  Type = 3,
}
/**
* Supported compression algorithms.
*
* Codecs added in format version X.Y can be read by readers based on X.Y and later.
* Codec support may vary between readers based on the format version and
* libraries available at runtime.
*/
export enum Compression {
  UNCOMPRESSED = 0,
  SNAPPY = 1,
  GZIP = 2,
  BROTLI = 3,
/**
* @deprecated as of Parquet 2.9.0.
* Switch to LZ4_RAW
*/
  LZ4 = 4,
  ZSTD = 5,
  LZ4_RAW = 6,
}
/**
* Controls the level of statistics to be computed by the writer
*/
export enum EnabledStatistics {
/**
* Compute no statistics
*/
  None = 0,
/**
* Compute chunk-level statistics but not page-level
*/
  Chunk = 1,
/**
* Compute page-level and chunk-level statistics
*/
  Page = 2,
}
/**
*/
export enum DateUnit {
  Day = 0,
  Millisecond = 1,
}
/**
*/
export enum UnionMode {
  Sparse = 0,
  Dense = 1,
}

export type SchemaMetadata = Map<string, string>;



export type FunctionTable = WebAssembly.Table;



export type Memory = WebAssembly.Memory;



export type FieldMetadata = Map<string, string>;


/**
*/
export class AsyncParquetFile {
  free(): void;
/**
* @param {string} url
*/
  constructor(url: string);
/**
* @param {number} batch_size
* @returns {AsyncParquetFile}
*/
  withBatchSize(batch_size: number): AsyncParquetFile;
/**
* @param {(string)[]} columns
* @returns {AsyncParquetFile}
*/
  selectColumns(columns: (string)[]): AsyncParquetFile;
/**
* @returns {ParquetMetaData}
*/
  metadata(): ParquetMetaData;
/**
* @param {number} i
* @returns {Promise<Table>}
*/
  readRowGroup(i: number): Promise<Table>;
/**
* @param {number | undefined} [concurrency]
* @returns {Promise<ReadableStream>}
*/
  stream(concurrency?: number): Promise<ReadableStream>;
}
/**
* Safety: Do not use this in a multi-threaded environment,
* (transitively depends on !Send web_sys::File)
*/
export class AsyncParquetLocalFile {
  free(): void;
/**
* @param {File} handle
*/
  constructor(handle: File);
/**
* @param {number} batch_size
* @returns {AsyncParquetLocalFile}
*/
  withBatchSize(batch_size: number): AsyncParquetLocalFile;
/**
* @param {(string)[]} columns
* @returns {AsyncParquetLocalFile}
*/
  selectColumns(columns: (string)[]): AsyncParquetLocalFile;
/**
* @returns {ParquetMetaData}
*/
  metadata(): ParquetMetaData;
/**
* @param {number} i
* @returns {Promise<Table>}
*/
  readRowGroup(i: number): Promise<Table>;
/**
* @param {number | undefined} [concurrency]
* @returns {Promise<ReadableStream>}
*/
  stream(concurrency?: number): Promise<ReadableStream>;
}
/**
* Opaque binary data of variable length.
*
* A single Binary array can store up to [`i32::MAX`] bytes
* of binary data in total
*/
export class Binary {
  free(): void;
}
/**
*/
export class BinaryData {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
}
/**
*/
export class BinaryVector {
  free(): void;
}
/**
* A boolean datatype representing the values `true` and `false`.
*/
export class Boolean {
  free(): void;
}
/**
*/
export class BooleanData {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
}
/**
*/
export class BooleanVector {
  free(): void;
}
/**
* Metadata for a Parquet column chunk.
*/
export class ColumnChunkMetaData {
  free(): void;
/**
* File where the column chunk is stored.
*
* If not set, assumed to belong to the same file as the metadata.
* This path is relative to the current file.
* @returns {string | undefined}
*/
  filePath(): string | undefined;
/**
* Byte offset in `file_path()`.
* @returns {bigint}
*/
  fileOffset(): bigint;
/**
* Path (or identifier) of this column.
* @returns {(string)[]}
*/
  columnPath(): (string)[];
/**
* Total number of values in this column chunk.
* @returns {bigint}
*/
  numValues(): bigint;
/**
* Returns the total compressed data size of this column chunk.
* @returns {bigint}
*/
  compressedSize(): bigint;
/**
* Returns the total uncompressed data size of this column chunk.
* @returns {bigint}
*/
  uncompressedSize(): bigint;
}
/**
* A 32-bit date representing the elapsed time since UNIX epoch (1970-01-01)
* in days (32 bits).
*/
export class Date32 {
  free(): void;
}
/**
* A 64-bit date representing the elapsed time since UNIX epoch (1970-01-01)
* in milliseconds (64 bits). Values are evenly divisible by 86400000.
*/
export class Date64 {
  free(): void;
}
/**
* Exact 128-bit width decimal value with precision and scale
*
* * precision is the total number of digits
* * scale is the number of digits past the decimal
*
* For example the number 123.45 has precision 5 and scale 2.
*
* In certain situations, scale could be negative number. For
* negative scale, it is the number of padding 0 to the right
* of the digits.
*
* For example the number 12300 could be treated as a decimal
* has precision 3 and scale -2.
*/
export class Decimal128 {
  free(): void;
}
/**
* Exact 256-bit width decimal value with precision and scale
*
* * precision is the total number of digits
* * scale is the number of digits past the decimal
*
* For example the number 123.45 has precision 5 and scale 2.
*
* In certain situations, scale could be negative number. For
* negative scale, it is the number of padding 0 to the right
* of the digits.
*
* For example the number 12300 could be treated as a decimal
* has precision 3 and scale -2.
*/
export class Decimal256 {
  free(): void;
}
/**
* A dictionary encoded array (`key_type`, `value_type`), where
* each array element is an index of `key_type` into an
* associated dictionary of `value_type`.
*
* Dictionary arrays are used to store columns of `value_type`
* that contain many repeated values using less memory, but with
* a higher CPU overhead for some operations.
*
* This type mostly used to represent low cardinality string
* arrays or a limited set of primitive types as integers.
*/
export class Dictionary {
  free(): void;
}
/**
* Measure of elapsed time in either seconds, milliseconds, microseconds or nanoseconds.
*/
export class Duration {
  free(): void;
}
/**
*/
export class FFIArrowArray {
  free(): void;
/**
* @returns {number}
*/
  addr(): number;
}
/**
*/
export class FFIArrowSchema {
  free(): void;
/**
* Access the pointer to the
* [`ArrowSchema`](https://arrow.apache.org/docs/format/CDataInterface.html#structure-definitions)
* struct. This can be viewed or copied (without serialization) to an Arrow JS `Field` by
* using [`arrow-js-ffi`](https://github.com/kylebarron/arrow-js-ffi). You can access the
* [`WebAssembly.Memory`](https://developer.mozilla.org/en-US/docs/WebAssembly/JavaScript_interface/Memory)
* instance by using {@linkcode wasmMemory}.
*
* **Example**:
*
* ```ts
* import { parseRecordBatch } from "arrow-js-ffi";
*
* const wasmRecordBatch: FFIRecordBatch = ...
* const wasmMemory: WebAssembly.Memory = wasmMemory();
*
* // Pass `true` to copy arrays across the boundary instead of creating views.
* const jsRecordBatch = parseRecordBatch(
*   wasmMemory.buffer,
*   wasmRecordBatch.arrayAddr(),
*   wasmRecordBatch.schemaAddr(),
*   true
* );
* ```
* @returns {number}
*/
  addr(): number;
}
/**
* A representation of an Arrow RecordBatch in WebAssembly memory exposed as FFI-compatible
* structs through the Arrow C Data Interface.
*/
export class FFIRecordBatch {
  free(): void;
/**
* Access the pointer to the
* [`ArrowArray`](https://arrow.apache.org/docs/format/CDataInterface.html#structure-definitions)
* struct. This can be viewed or copied (without serialization) to an Arrow JS `RecordBatch` by
* using [`arrow-js-ffi`](https://github.com/kylebarron/arrow-js-ffi). You can access the
* [`WebAssembly.Memory`](https://developer.mozilla.org/en-US/docs/WebAssembly/JavaScript_interface/Memory)
* instance by using {@linkcode wasmMemory}.
*
* **Example**:
*
* ```ts
* import { parseRecordBatch } from "arrow-js-ffi";
*
* const wasmRecordBatch: FFIRecordBatch = ...
* const wasmMemory: WebAssembly.Memory = wasmMemory();
*
* // Pass `true` to copy arrays across the boundary instead of creating views.
* const jsRecordBatch = parseRecordBatch(
*   wasmMemory.buffer,
*   wasmRecordBatch.arrayAddr(),
*   wasmRecordBatch.schemaAddr(),
*   true
* );
* ```
* @returns {number}
*/
  arrayAddr(): number;
/**
* Access the pointer to the
* [`ArrowSchema`](https://arrow.apache.org/docs/format/CDataInterface.html#structure-definitions)
* struct. This can be viewed or copied (without serialization) to an Arrow JS `Field` by
* using [`arrow-js-ffi`](https://github.com/kylebarron/arrow-js-ffi). You can access the
* [`WebAssembly.Memory`](https://developer.mozilla.org/en-US/docs/WebAssembly/JavaScript_interface/Memory)
* instance by using {@linkcode wasmMemory}.
*
* **Example**:
*
* ```ts
* import { parseRecordBatch } from "arrow-js-ffi";
*
* const wasmRecordBatch: FFIRecordBatch = ...
* const wasmMemory: WebAssembly.Memory = wasmMemory();
*
* // Pass `true` to copy arrays across the boundary instead of creating views.
* const jsRecordBatch = parseRecordBatch(
*   wasmMemory.buffer,
*   wasmRecordBatch.arrayAddr(),
*   wasmRecordBatch.schemaAddr(),
*   true
* );
* ```
* @returns {number}
*/
  schemaAddr(): number;
}
/**
* A representation of an Arrow Table in WebAssembly memory exposed as FFI-compatible
* structs through the Arrow C Data Interface.
*/
export class FFITable {
  free(): void;
/**
* Get the total number of record batches in the table
* @returns {number}
*/
  numBatches(): number;
/**
* Get the pointer to one ArrowSchema FFI struct
* @returns {number}
*/
  schemaAddr(): number;
/**
* Get the pointer to one ArrowArray FFI struct for a given chunk index and column index
*
* Access the pointer to one
* [`ArrowArray`](https://arrow.apache.org/docs/format/CDataInterface.html#structure-definitions)
* struct representing one of the internal `RecordBatch`es. This can be viewed or copied (without serialization) to an Arrow JS `RecordBatch` by
* using [`arrow-js-ffi`](https://github.com/kylebarron/arrow-js-ffi). You can access the
* [`WebAssembly.Memory`](https://developer.mozilla.org/en-US/docs/WebAssembly/JavaScript_interface/Memory)
* instance by using {@linkcode wasmMemory}.
*
* **Example**:
*
* ```ts
* import * as arrow from "apache-arrow";
* import { parseRecordBatch } from "arrow-js-ffi";
*
* const wasmTable: FFITable = ...
* const wasmMemory: WebAssembly.Memory = wasmMemory();
*
* const jsBatches: arrow.RecordBatch[] = []
* for (let i = 0; i < wasmTable.numBatches(); i++) {
*   // Pass `true` to copy arrays across the boundary instead of creating views.
*   const jsRecordBatch = parseRecordBatch(
*     wasmMemory.buffer,
*     wasmTable.arrayAddr(i),
*     wasmTable.schemaAddr(),
*     true
*   );
*   jsBatches.push(jsRecordBatch);
* }
* const jsTable = new arrow.Table(jsBatches);
* ```
*
* @param chunk number The chunk index to use
* @returns number pointer to an ArrowArray FFI struct in Wasm memory
* @param {number} chunk
* @returns {number}
*/
  arrayAddr(chunk: number): number;
/**
* @returns {Uint32Array}
*/
  arrayAddrs(): Uint32Array;
/**
*/
  drop(): void;
}
/**
*/
export class Field {
  free(): void;
/**
* Export this field to an `FFIArrowSchema`` object, which can be read with arrow-js-ffi.
* @returns {FFIArrowSchema}
*/
  to_ffi(): FFIArrowSchema;
/**
* Returns the `Field`'s name.
* @returns {string}
*/
  name(): string;
/**
* Sets the name of this `Field` and returns a new object
* @param {string} name
* @returns {Field}
*/
  with_name(name: string): Field;
/**
* @returns {any}
*/
  data_type(): any;
/**
* Indicates whether this [`Field`] supports null values.
* @returns {boolean}
*/
  is_nullable(): boolean;
/**
* @returns {FieldMetadata}
*/
  metadata(): FieldMetadata;
/**
* Sets the metadata of this `Field` to be `metadata` and returns a new object
* @param {FieldMetadata} metadata
* @returns {Field}
*/
  with_metadata(metadata: FieldMetadata): Field;
}
/**
* Metadata for a Parquet file.
*/
export class FileMetaData {
  free(): void;
/**
* Returns version of this file.
* @returns {number}
*/
  version(): number;
/**
* Returns number of rows in the file.
* @returns {bigint}
*/
  numRows(): bigint;
/**
* String message for application that wrote this file.
*
* This should have the following format:
* `<application> version <application version> (build <application build hash>)`.
*
* ```shell
* parquet-mr version 1.8.0 (build 0fda28af84b9746396014ad6a415b90592a98b3b)
* ```
* @returns {string | undefined}
*/
  createdBy(): string | undefined;
/**
* Returns key_value_metadata of this file.
* @returns {Map<any, any>}
*/
  keyValueMetadata(): Map<any, any>;
}
/**
* Opaque binary data of fixed size.
* Enum parameter specifies the number of bytes per value.
*/
export class FixedSizeBinary {
  free(): void;
}
/**
* A list of some logical data type with fixed length.
*/
export class FixedSizeList {
  free(): void;
}
/**
* A 16-bit floating point number.
*/
export class Float16 {
  free(): void;
}
/**
* A 32-bit floating point number.
*/
export class Float32 {
  free(): void;
}
/**
*/
export class Float32Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {Float32Array}
*/
  to_typed_array(): Float32Array;
}
/**
*/
export class Float32Vector {
  free(): void;
}
/**
* A 64-bit floating point number.
*/
export class Float64 {
  free(): void;
}
/**
*/
export class Float64Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {Float64Array}
*/
  to_typed_array(): Float64Array;
}
/**
*/
export class Float64Vector {
  free(): void;
}
/**
* A signed 16-bit integer.
*/
export class Int16 {
  free(): void;
}
/**
*/
export class Int16Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {Int16Array}
*/
  to_typed_array(): Int16Array;
}
/**
*/
export class Int16Vector {
  free(): void;
}
/**
* A signed 32-bit integer.
*/
export class Int32 {
  free(): void;
}
/**
*/
export class Int32Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {Int32Array}
*/
  to_typed_array(): Int32Array;
}
/**
*/
export class Int32Vector {
  free(): void;
}
/**
* A signed 64-bit integer.
*/
export class Int64 {
  free(): void;
}
/**
*/
export class Int64Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {BigInt64Array}
*/
  to_typed_array(): BigInt64Array;
}
/**
*/
export class Int64Vector {
  free(): void;
}
/**
* A signed 8-bit integer.
*/
export class Int8 {
  free(): void;
}
/**
*/
export class Int8Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {Int8Array}
*/
  to_typed_array(): Int8Array;
}
/**
*/
export class Int8Vector {
  free(): void;
}
/**
* A "calendar" interval which models types that don't necessarily
* have a precise duration without the context of a base timestamp (e.g.
* days can differ in length during day light savings time transitions).
*/
export class Interval {
  free(): void;
}
/**
*/
export class IntoUnderlyingByteSource {
  free(): void;
/**
* @param {ReadableByteStreamController} controller
*/
  start(controller: ReadableByteStreamController): void;
/**
* @param {ReadableByteStreamController} controller
* @returns {Promise<any>}
*/
  pull(controller: ReadableByteStreamController): Promise<any>;
/**
*/
  cancel(): void;
/**
*/
  readonly autoAllocateChunkSize: number;
/**
*/
  readonly type: string;
}
/**
*/
export class IntoUnderlyingSink {
  free(): void;
/**
* @param {any} chunk
* @returns {Promise<any>}
*/
  write(chunk: any): Promise<any>;
/**
* @returns {Promise<any>}
*/
  close(): Promise<any>;
/**
* @param {any} reason
* @returns {Promise<any>}
*/
  abort(reason: any): Promise<any>;
}
/**
*/
export class IntoUnderlyingSource {
  free(): void;
/**
* @param {ReadableStreamDefaultController} controller
* @returns {Promise<any>}
*/
  pull(controller: ReadableStreamDefaultController): Promise<any>;
/**
*/
  cancel(): void;
}
/**
* Opaque binary data of variable length and 64-bit offsets.
*
* A single LargeBinary array can store up to [`i64::MAX`] bytes
* of binary data in total
*/
export class LargeBinary {
  free(): void;
}
/**
*/
export class LargeBinaryData {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
}
/**
*/
export class LargeBinaryVector {
  free(): void;
}
/**
* A list of some logical data type with variable length and 64-bit offsets.
*
* A single LargeList array can store up to [`i64::MAX`] elements in total
*/
export class LargeList {
  free(): void;
}
/**
*/
export class LargeListData {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
}
/**
*/
export class LargeListVector {
  free(): void;
}
/**
* A variable-length string in Unicode with UFT-8 encoding and 64-bit offsets.
*
* A single LargeUtf8 array can store up to [`i64::MAX`] bytes
* of string data in total
*/
export class LargeUtf8 {
  free(): void;
}
/**
*/
export class LargeUtf8Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
}
/**
*/
export class LargeUtf8Vector {
  free(): void;
}
/**
* A list of some logical data type with variable length.
*
* A single List array can store up to [`i32::MAX`] elements in total
*/
export class List {
  free(): void;
}
/**
*/
export class ListData {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
}
/**
*/
export class ListVector {
  free(): void;
}
/**
* A Map is a logical nested type that is represented as
*
* `List<entries: Struct<key: K, value: V>>`
*
* The keys and values are each respectively contiguous.
* The key and value types are not constrained, but keys should be
* hashable and unique.
* Whether the keys are sorted can be set in the `bool` after the `Field`.
*
* In a field with Map type, the field has a child Struct field, which then
* has two children: key type and the second the value type. The names of the
* child fields may be respectively "entries", "key", and "value", but this is
* not enforced.
*/
export class Map_ {
  free(): void;
}
/**
* Null type
*/
export class Null {
  free(): void;
}
/**
* Global Parquet metadata.
*/
export class ParquetMetaData {
  free(): void;
/**
* Returns file metadata as reference.
* @returns {FileMetaData}
*/
  fileMetadata(): FileMetaData;
/**
* Returns number of row groups in this file.
* @returns {number}
*/
  numRowGroups(): number;
/**
* Returns row group metadata for `i`th position.
* Position should be less than number of row groups `num_row_groups`.
* @param {number} i
* @returns {RowGroupMetaData}
*/
  rowGroup(i: number): RowGroupMetaData;
}
/**
* A group of columns of equal length in WebAssembly memory with an associated {@linkcode Schema}.
*/
export class RecordBatch {
  free(): void;
/**
* Export this RecordBatch to FFI structs according to the Arrow C Data Interface.
*
* This method **does not consume** the RecordBatch, so you must remember to call {@linkcode
* RecordBatch.free} to release the resources. The underlying arrays are reference counted, so
* this method does not copy data, it only prevents the data from being released.
* @returns {FFIRecordBatch}
*/
  toFFI(): FFIRecordBatch;
/**
* Export this RecordBatch to FFI structs according to the Arrow C Data Interface.
*
* This method **does consume** the RecordBatch, so the original RecordBatch will be
* inaccessible after this call. You must still call {@linkcode FFIRecordBatch.free} after
* you've finished using the FFIRecordBatch.
* @returns {FFIRecordBatch}
*/
  intoFFI(): FFIRecordBatch;
/**
* Consume this RecordBatch and convert to an Arrow IPC Stream buffer
* @returns {Uint8Array}
*/
  intoIPCStream(): Uint8Array;
/**
* Override the schema of this [`RecordBatch`]
*
* Returns an error if `schema` is not a superset of the current schema
* as determined by [`Schema::contains`]
* @param {Schema} schema
* @returns {RecordBatch}
*/
  with_schema(schema: Schema): RecordBatch;
/**
* Return a new RecordBatch where each column is sliced
* according to `offset` and `length`
* @param {number} offset
* @param {number} length
* @returns {RecordBatch}
*/
  slice(offset: number, length: number): RecordBatch;
/**
* Returns the total number of bytes of memory occupied physically by this batch.
* @returns {number}
*/
  get_array_memory_size(): number;
/**
* The number of columns in this RecordBatch.
*/
  readonly numColumns: number;
/**
* The number of rows in this RecordBatch.
*/
  readonly numRows: number;
/**
* The {@linkcode Schema} of this RecordBatch.
*/
  readonly schema: Schema;
}
/**
* Metadata for a Parquet row group.
*/
export class RowGroupMetaData {
  free(): void;
/**
* Number of columns in this row group.
* @returns {number}
*/
  numColumns(): number;
/**
* Returns column chunk metadata for `i`th column.
* @param {number} i
* @returns {ColumnChunkMetaData}
*/
  column(i: number): ColumnChunkMetaData;
/**
* Number of rows in this row group.
* @returns {bigint}
*/
  numRows(): bigint;
/**
* Total byte size of all uncompressed column data in this row group.
* @returns {bigint}
*/
  totalByteSize(): bigint;
/**
* Total size of all compressed column data in this row group.
* @returns {bigint}
*/
  compressedSize(): bigint;
}
/**
* A run-end encoding (REE) is a variation of run-length encoding (RLE). These
* encodings are well-suited for representing data containing sequences of the
* same value, called runs. Each run is represented as a value and an integer giving
* the index in the array where the run ends.
*
* A run-end encoded array has no buffers by itself, but has two child arrays. The
* first child array, called the run ends array, holds either 16, 32, or 64-bit
* signed integers. The actual values of each run are held in the second child array.
*
* These child arrays are prescribed the standard names of "run_ends" and "values"
* respectively.
*/
export class RunEndEncoded {
  free(): void;
}
/**
* A named collection of types that defines the column names and types in a RecordBatch or Table
* data structure.
*
* A Schema can also contain extra user-defined metadata either at the Table or Column level.
* Column-level metadata is often used to define [extension
* types](https://arrow.apache.org/docs/format/Columnar.html#extension-types).
*/
export class Schema {
  free(): void;
/**
* Export this schema to an FFIArrowSchema object, which can be read with arrow-js-ffi.
* @returns {FFIArrowSchema}
*/
  to_ffi(): FFIArrowSchema;
/**
* Returns an immutable reference of a specific [`Field`] instance selected using an
* offset within the internal `fields` vector.
* @param {number} i
* @returns {Field}
*/
  field(i: number): Field;
/**
* Returns an immutable reference of a specific [`Field`] instance selected by name.
* @param {string} name
* @returns {Field}
*/
  field_with_name(name: string): Field;
/**
* Sets the metadata of this `Schema` to be `metadata` and returns a new object
* @param {SchemaMetadata} metadata
* @returns {Schema}
*/
  with_metadata(metadata: SchemaMetadata): Schema;
/**
* @param {string} name
* @returns {number}
*/
  index_of(name: string): number;
/**
* Returns an immutable reference to the Map of custom metadata key-value pairs.
* @returns {SchemaMetadata}
*/
  metadata(): SchemaMetadata;
}
/**
* A nested datatype that contains a number of sub-fields.
*/
export class Struct {
  free(): void;
}
/**
* A Table in WebAssembly memory conforming to the Apache Arrow spec.
*
* A Table consists of one or more {@linkcode RecordBatch} objects plus a {@linkcode Schema} that
* each RecordBatch conforms to.
*/
export class Table {
  free(): void;
/**
* Access a RecordBatch from the Table by index.
*
* @param index The positional index of the RecordBatch to retrieve.
* @returns a RecordBatch or `null` if out of range.
* @param {number} index
* @returns {RecordBatch | undefined}
*/
  recordBatch(index: number): RecordBatch | undefined;
/**
* Export this Table to FFI structs according to the Arrow C Data Interface.
*
* This method **does not consume** the Table, so you must remember to call {@linkcode
* Table.free} to release the resources. The underlying arrays are reference counted, so
* this method does not copy data, it only prevents the data from being released.
* @returns {FFITable}
*/
  toFFI(): FFITable;
/**
* Export this Table to FFI structs according to the Arrow C Data Interface.
*
* This method **does consume** the Table, so the original Table will be
* inaccessible after this call. You must still call {@linkcode FFITable.free} after
* you've finished using the FFITable.
* @returns {FFITable}
*/
  intoFFI(): FFITable;
/**
* Consume this table and convert to an Arrow IPC Stream buffer
* @returns {Uint8Array}
*/
  intoIPCStream(): Uint8Array;
/**
* Create a table from an Arrow IPC Stream buffer
* @param {Uint8Array} buf
* @returns {Table}
*/
  static fromIPCStream(buf: Uint8Array): Table;
/**
* Returns the total number of bytes of memory occupied physically by all batches in this
* table.
* @returns {number}
*/
  get_array_memory_size(): number;
/**
* The number of batches in the Table
*/
  readonly numBatches: number;
/**
* Access the Table's {@linkcode Schema}.
*/
  readonly schema: Schema;
}
/**
* A 32-bit time representing the elapsed time since midnight in the unit of `TimeUnit`.
*/
export class Time32 {
  free(): void;
}
/**
* A 64-bit time representing the elapsed time since midnight in the unit of `TimeUnit`.
*/
export class Time64 {
  free(): void;
}
/**
* A timestamp with an optional timezone.
*
* Time is measured as a Unix epoch, counting the seconds from
* 00:00:00.000 on 1 January 1970, excluding leap seconds,
* as a 64-bit integer.
*
* The time zone is a string indicating the name of a time zone, one of:
*
* * As used in the Olson time zone database (the "tz database" or
*   "tzdata"), such as "America/New_York"
* * An absolute time zone offset of the form +XX:XX or -XX:XX, such as +07:30
*
* Timestamps with a non-empty timezone
* ------------------------------------
*
* If a Timestamp column has a non-empty timezone value, its epoch is
* 1970-01-01 00:00:00 (January 1st 1970, midnight) in the *UTC* timezone
* (the Unix epoch), regardless of the Timestamp's own timezone.
*
* Therefore, timestamp values with a non-empty timezone correspond to
* physical points in time together with some additional information about
* how the data was obtained and/or how to display it (the timezone).
*
*   For example, the timestamp value 0 with the timezone string "Europe/Paris"
*   corresponds to "January 1st 1970, 00h00" in the UTC timezone, but the
*   application may prefer to display it as "January 1st 1970, 01h00" in
*   the Europe/Paris timezone (which is the same physical point in time).
*
* One consequence is that timestamp values with a non-empty timezone
* can be compared and ordered directly, since they all share the same
* well-known point of reference (the Unix epoch).
*
* Timestamps with an unset / empty timezone
* -----------------------------------------
*
* If a Timestamp column has no timezone value, its epoch is
* 1970-01-01 00:00:00 (January 1st 1970, midnight) in an *unknown* timezone.
*
* Therefore, timestamp values without a timezone cannot be meaningfully
* interpreted as physical points in time, but only as calendar / clock
* indications ("wall clock time") in an unspecified timezone.
*
*   For example, the timestamp value 0 with an empty timezone string
*   corresponds to "January 1st 1970, 00h00" in an unknown timezone: there
*   is not enough information to interpret it as a well-defined physical
*   point in time.
*
* One consequence is that timestamp values without a timezone cannot
* be reliably compared or ordered, since they may have different points of
* reference.  In particular, it is *not* possible to interpret an unset
* or empty timezone as the same as "UTC".
*
* Conversion between timezones
* ----------------------------
*
* If a Timestamp column has a non-empty timezone, changing the timezone
* to a different non-empty value is a metadata-only operation:
* the timestamp values need not change as their point of reference remains
* the same (the Unix epoch).
*
* However, if a Timestamp column has no timezone value, changing it to a
* non-empty value requires to think about the desired semantics.
* One possibility is to assume that the original timestamp values are
* relative to the epoch of the timezone being set; timestamp values should
* then adjusted to the Unix epoch (for example, changing the timezone from
* empty to "Europe/Paris" would require converting the timestamp values
* from "Europe/Paris" to "UTC", which seems counter-intuitive but is
* nevertheless correct).
*/
export class Timestamp {
  free(): void;
}
/**
* An unsigned 16-bit integer.
*/
export class UInt16 {
  free(): void;
}
/**
* An unsigned 32-bit integer.
*/
export class UInt32 {
  free(): void;
}
/**
* An unsigned 64-bit integer.
*/
export class UInt64 {
  free(): void;
}
/**
* An unsigned 8-bit integer.
*/
export class UInt8 {
  free(): void;
}
/**
*/
export class Uint16Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {Uint16Array}
*/
  to_typed_array(): Uint16Array;
}
/**
*/
export class Uint16Vector {
  free(): void;
}
/**
*/
export class Uint32Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {Uint32Array}
*/
  to_typed_array(): Uint32Array;
}
/**
*/
export class Uint32Vector {
  free(): void;
}
/**
*/
export class Uint64Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {BigUint64Array}
*/
  to_typed_array(): BigUint64Array;
}
/**
*/
export class Uint64Vector {
  free(): void;
}
/**
*/
export class Uint8Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
/**
* Convert the values of this `Data` instance to a typed array in the JavaScript heap.
*
* This will silently ignore any null values.
*
* Note this doesn't take the offset of this array into account.
* @returns {Uint8Array}
*/
  to_typed_array(): Uint8Array;
}
/**
*/
export class Uint8Vector {
  free(): void;
}
/**
* A nested datatype that can represent slots of differing types. Components:
*
* 1. [`UnionFields`]
* 2. The type of union (Sparse or Dense)
*/
export class Union {
  free(): void;
}
/**
* A variable-length string in Unicode with UTF-8 encoding
*
* A single Utf8 array can store up to [`i32::MAX`] bytes
* of string data in total
*/
export class Utf8 {
  free(): void;
}
/**
*/
export class Utf8Data {
  free(): void;
/**
* @returns {FFIArrowArray}
*/
  to_ffi(): FFIArrowArray;
}
/**
*/
export class Utf8Vector {
  free(): void;
}
/**
* Immutable struct to hold writing configuration for `writeParquet`.
*
* Use {@linkcode WriterPropertiesBuilder} to create a configuration, then call {@linkcode
* WriterPropertiesBuilder.build} to create an instance of `WriterProperties`.
*/
export class WriterProperties {
  free(): void;
}
/**
* Builder to create a writing configuration for `writeParquet`
*
* Call {@linkcode build} on the finished builder to create an immputable {@linkcode WriterProperties} to pass to `writeParquet`
*/
export class WriterPropertiesBuilder {
  free(): void;
/**
* Returns default state of the builder.
*/
  constructor();
/**
* Finalizes the configuration and returns immutable writer properties struct.
* @returns {WriterProperties}
*/
  build(): WriterProperties;
/**
* Sets writer version.
* @param {WriterVersion} value
* @returns {WriterPropertiesBuilder}
*/
  setWriterVersion(value: WriterVersion): WriterPropertiesBuilder;
/**
* Sets data page size limit.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setDataPageSizeLimit(value: number): WriterPropertiesBuilder;
/**
* Sets dictionary page size limit.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setDictionaryPageSizeLimit(value: number): WriterPropertiesBuilder;
/**
* Sets write batch size.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setWriteBatchSize(value: number): WriterPropertiesBuilder;
/**
* Sets maximum number of rows in a row group.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setMaxRowGroupSize(value: number): WriterPropertiesBuilder;
/**
* Sets "created by" property.
* @param {string} value
* @returns {WriterPropertiesBuilder}
*/
  setCreatedBy(value: string): WriterPropertiesBuilder;
/**
* Sets encoding for any column.
*
* If dictionary is not enabled, this is treated as a primary encoding for all
* columns. In case when dictionary is enabled for any column, this value is
* considered to be a fallback encoding for that column.
*
* Panics if user tries to set dictionary encoding here, regardless of dictionary
* encoding flag being set.
* @param {Encoding} value
* @returns {WriterPropertiesBuilder}
*/
  setEncoding(value: Encoding): WriterPropertiesBuilder;
/**
* Sets compression codec for any column.
* @param {Compression} value
* @returns {WriterPropertiesBuilder}
*/
  setCompression(value: Compression): WriterPropertiesBuilder;
/**
* Sets flag to enable/disable dictionary encoding for any column.
*
* Use this method to set dictionary encoding, instead of explicitly specifying
* encoding in `set_encoding` method.
* @param {boolean} value
* @returns {WriterPropertiesBuilder}
*/
  setDictionaryEnabled(value: boolean): WriterPropertiesBuilder;
/**
* Sets flag to enable/disable statistics for any column.
* @param {EnabledStatistics} value
* @returns {WriterPropertiesBuilder}
*/
  setStatisticsEnabled(value: EnabledStatistics): WriterPropertiesBuilder;
/**
* Sets max statistics size for any column.
* Applicable only if statistics are enabled.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setMaxStatisticsSize(value: number): WriterPropertiesBuilder;
/**
* Sets encoding for a column.
* Takes precedence over globally defined settings.
*
* If dictionary is not enabled, this is treated as a primary encoding for this
* column. In case when dictionary is enabled for this column, either through
* global defaults or explicitly, this value is considered to be a fallback
* encoding for this column.
*
* Panics if user tries to set dictionary encoding here, regardless of dictionary
* encoding flag being set.
* @param {string} col
* @param {Encoding} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnEncoding(col: string, value: Encoding): WriterPropertiesBuilder;
/**
* Sets compression codec for a column.
* Takes precedence over globally defined settings.
* @param {string} col
* @param {Compression} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnCompression(col: string, value: Compression): WriterPropertiesBuilder;
/**
* Sets flag to enable/disable dictionary encoding for a column.
* Takes precedence over globally defined settings.
* @param {string} col
* @param {boolean} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnDictionaryEnabled(col: string, value: boolean): WriterPropertiesBuilder;
/**
* Sets flag to enable/disable statistics for a column.
* Takes precedence over globally defined settings.
* @param {string} col
* @param {EnabledStatistics} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnStatisticsEnabled(col: string, value: EnabledStatistics): WriterPropertiesBuilder;
/**
* Sets max size for statistics for a column.
* Takes precedence over globally defined settings.
* @param {string} col
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnMaxStatisticsSize(col: string, value: number): WriterPropertiesBuilder;
}

export type InitInput = RequestInfo | URL | Response | BufferSource | WebAssembly.Module;

export interface InitOutput {
  readonly memory: WebAssembly.Memory;
  readonly __wbg_asyncparquetfile_free: (a: number) => void;
  readonly asyncparquetfile_new: (a: number, b: number) => number;
  readonly asyncparquetfile_withBatchSize: (a: number, b: number) => number;
  readonly asyncparquetfile_selectColumns: (a: number, b: number, c: number, d: number) => void;
  readonly asyncparquetfile_metadata: (a: number, b: number) => void;
  readonly asyncparquetfile_readRowGroup: (a: number, b: number) => number;
  readonly asyncparquetfile_stream: (a: number, b: number, c: number) => number;
  readonly __wbg_asyncparquetlocalfile_free: (a: number) => void;
  readonly asyncparquetlocalfile_new: (a: number) => number;
  readonly asyncparquetlocalfile_withBatchSize: (a: number, b: number) => number;
  readonly asyncparquetlocalfile_selectColumns: (a: number, b: number, c: number, d: number) => void;
  readonly asyncparquetlocalfile_metadata: (a: number, b: number) => void;
  readonly asyncparquetlocalfile_readRowGroup: (a: number, b: number) => number;
  readonly asyncparquetlocalfile_stream: (a: number, b: number, c: number) => number;
  readonly __wbg_parquetmetadata_free: (a: number) => void;
  readonly parquetmetadata_fileMetadata: (a: number) => number;
  readonly parquetmetadata_numRowGroups: (a: number) => number;
  readonly parquetmetadata_rowGroup: (a: number, b: number) => number;
  readonly __wbg_filemetadata_free: (a: number) => void;
  readonly filemetadata_version: (a: number) => number;
  readonly filemetadata_numRows: (a: number) => number;
  readonly filemetadata_createdBy: (a: number, b: number) => void;
  readonly filemetadata_keyValueMetadata: (a: number, b: number) => void;
  readonly __wbg_rowgroupmetadata_free: (a: number) => void;
  readonly rowgroupmetadata_numColumns: (a: number) => number;
  readonly rowgroupmetadata_column: (a: number, b: number) => number;
  readonly rowgroupmetadata_numRows: (a: number) => number;
  readonly rowgroupmetadata_totalByteSize: (a: number) => number;
  readonly rowgroupmetadata_compressedSize: (a: number) => number;
  readonly __wbg_columnchunkmetadata_free: (a: number) => void;
  readonly columnchunkmetadata_filePath: (a: number, b: number) => void;
  readonly columnchunkmetadata_fileOffset: (a: number) => number;
  readonly columnchunkmetadata_columnPath: (a: number, b: number) => void;
  readonly columnchunkmetadata_numValues: (a: number) => number;
  readonly columnchunkmetadata_compressedSize: (a: number) => number;
  readonly columnchunkmetadata_uncompressedSize: (a: number) => number;
  readonly __wbg_writerproperties_free: (a: number) => void;
  readonly writerpropertiesbuilder_new: () => number;
  readonly writerpropertiesbuilder_build: (a: number) => number;
  readonly writerpropertiesbuilder_setWriterVersion: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setDataPageSizeLimit: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setDictionaryPageSizeLimit: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setWriteBatchSize: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setMaxRowGroupSize: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setCreatedBy: (a: number, b: number, c: number) => number;
  readonly writerpropertiesbuilder_setEncoding: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setCompression: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setDictionaryEnabled: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setStatisticsEnabled: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setMaxStatisticsSize: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setColumnEncoding: (a: number, b: number, c: number, d: number) => number;
  readonly writerpropertiesbuilder_setColumnCompression: (a: number, b: number, c: number, d: number) => number;
  readonly writerpropertiesbuilder_setColumnDictionaryEnabled: (a: number, b: number, c: number, d: number) => number;
  readonly writerpropertiesbuilder_setColumnStatisticsEnabled: (a: number, b: number, c: number, d: number) => number;
  readonly writerpropertiesbuilder_setColumnMaxStatisticsSize: (a: number, b: number, c: number, d: number) => number;
  readonly __wbg_writerpropertiesbuilder_free: (a: number) => void;
  readonly readParquet: (a: number, b: number, c: number) => void;
  readonly writeParquet: (a: number, b: number, c: number) => void;
  readonly readParquetStream: (a: number, b: number, c: number, d: number) => number;
  readonly __wbg_intounderlyingbytesource_free: (a: number) => void;
  readonly intounderlyingbytesource_type: (a: number, b: number) => void;
  readonly intounderlyingbytesource_autoAllocateChunkSize: (a: number) => number;
  readonly intounderlyingbytesource_start: (a: number, b: number) => void;
  readonly intounderlyingbytesource_pull: (a: number, b: number) => number;
  readonly intounderlyingbytesource_cancel: (a: number) => void;
  readonly __wbg_intounderlyingsource_free: (a: number) => void;
  readonly intounderlyingsource_pull: (a: number, b: number) => number;
  readonly intounderlyingsource_cancel: (a: number) => void;
  readonly __wbg_intounderlyingsink_free: (a: number) => void;
  readonly intounderlyingsink_write: (a: number, b: number) => number;
  readonly intounderlyingsink_close: (a: number) => number;
  readonly intounderlyingsink_abort: (a: number, b: number) => number;
  readonly __wbg_timestamp_free: (a: number) => void;
  readonly __wbg_duration_free: (a: number) => void;
  readonly __wbg_interval_free: (a: number) => void;
  readonly __wbg_binary_free: (a: number) => void;
  readonly __wbg_fixedsizebinary_free: (a: number) => void;
  readonly __wbg_fixedsizelist_free: (a: number) => void;
  readonly __wbg_largelist_free: (a: number) => void;
  readonly __wbg_struct_free: (a: number) => void;
  readonly __wbg_union_free: (a: number) => void;
  readonly __wbg_dictionary_free: (a: number) => void;
  readonly __wbg_decimal128_free: (a: number) => void;
  readonly __wbg_map__free: (a: number) => void;
  readonly __wbg_runendencoded_free: (a: number) => void;
  readonly __wbg_time64_free: (a: number) => void;
  readonly __wbg_time32_free: (a: number) => void;
  readonly __wbg_list_free: (a: number) => void;
  readonly __wbg_decimal256_free: (a: number) => void;
  readonly __wbg_int8_free: (a: number) => void;
  readonly __wbg_null_free: (a: number) => void;
  readonly __wbg_int16_free: (a: number) => void;
  readonly __wbg_int32_free: (a: number) => void;
  readonly __wbg_int64_free: (a: number) => void;
  readonly __wbg_uint8_free: (a: number) => void;
  readonly __wbg_uint16_free: (a: number) => void;
  readonly __wbg_uint32_free: (a: number) => void;
  readonly __wbg_uint64_free: (a: number) => void;
  readonly __wbg_float16_free: (a: number) => void;
  readonly __wbg_float32_free: (a: number) => void;
  readonly __wbg_float64_free: (a: number) => void;
  readonly __wbg_date32_free: (a: number) => void;
  readonly __wbg_date64_free: (a: number) => void;
  readonly __wbg_boolean_free: (a: number) => void;
  readonly __wbg_largebinary_free: (a: number) => void;
  readonly __wbg_utf8_free: (a: number) => void;
  readonly __wbg_largeutf8_free: (a: number) => void;
  readonly __wbg_booleandata_free: (a: number) => void;
  readonly booleandata_to_ffi: (a: number, b: number) => void;
  readonly uint8data_to_ffi: (a: number, b: number) => void;
  readonly uint16data_to_ffi: (a: number, b: number) => void;
  readonly uint32data_to_ffi: (a: number, b: number) => void;
  readonly uint64data_to_ffi: (a: number, b: number) => void;
  readonly int8data_to_ffi: (a: number, b: number) => void;
  readonly int16data_to_ffi: (a: number, b: number) => void;
  readonly int32data_to_ffi: (a: number, b: number) => void;
  readonly int64data_to_ffi: (a: number, b: number) => void;
  readonly __wbg_float32data_free: (a: number) => void;
  readonly float32data_to_ffi: (a: number, b: number) => void;
  readonly float64data_to_ffi: (a: number, b: number) => void;
  readonly utf8data_to_ffi: (a: number, b: number) => void;
  readonly largeutf8data_to_ffi: (a: number, b: number) => void;
  readonly listdata_to_ffi: (a: number, b: number) => void;
  readonly __wbg_largelistdata_free: (a: number) => void;
  readonly largelistdata_to_ffi: (a: number, b: number) => void;
  readonly __wbg_binarydata_free: (a: number) => void;
  readonly binarydata_to_ffi: (a: number, b: number) => void;
  readonly largebinarydata_to_ffi: (a: number, b: number) => void;
  readonly __wbg_listdata_free: (a: number) => void;
  readonly __wbg_uint16data_free: (a: number) => void;
  readonly __wbg_uint32data_free: (a: number) => void;
  readonly __wbg_uint64data_free: (a: number) => void;
  readonly __wbg_uint8data_free: (a: number) => void;
  readonly __wbg_int8data_free: (a: number) => void;
  readonly __wbg_int32data_free: (a: number) => void;
  readonly __wbg_int64data_free: (a: number) => void;
  readonly __wbg_int16data_free: (a: number) => void;
  readonly __wbg_float64data_free: (a: number) => void;
  readonly __wbg_utf8data_free: (a: number) => void;
  readonly __wbg_largeutf8data_free: (a: number) => void;
  readonly __wbg_largebinarydata_free: (a: number) => void;
  readonly __wbg_booleanvector_free: (a: number) => void;
  readonly __wbg_uint8vector_free: (a: number) => void;
  readonly __wbg_uint16vector_free: (a: number) => void;
  readonly __wbg_uint32vector_free: (a: number) => void;
  readonly __wbg_uint64vector_free: (a: number) => void;
  readonly __wbg_int8vector_free: (a: number) => void;
  readonly __wbg_int16vector_free: (a: number) => void;
  readonly __wbg_int32vector_free: (a: number) => void;
  readonly __wbg_int64vector_free: (a: number) => void;
  readonly __wbg_float32vector_free: (a: number) => void;
  readonly __wbg_float64vector_free: (a: number) => void;
  readonly __wbg_utf8vector_free: (a: number) => void;
  readonly __wbg_largeutf8vector_free: (a: number) => void;
  readonly __wbg_listvector_free: (a: number) => void;
  readonly __wbg_largelistvector_free: (a: number) => void;
  readonly __wbg_binaryvector_free: (a: number) => void;
  readonly __wbg_largebinaryvector_free: (a: number) => void;
  readonly uint8data_to_typed_array: (a: number, b: number) => void;
  readonly uint16data_to_typed_array: (a: number, b: number) => void;
  readonly uint32data_to_typed_array: (a: number, b: number) => void;
  readonly uint64data_to_typed_array: (a: number, b: number) => void;
  readonly int8data_to_typed_array: (a: number, b: number) => void;
  readonly int16data_to_typed_array: (a: number, b: number) => void;
  readonly int32data_to_typed_array: (a: number, b: number) => void;
  readonly int64data_to_typed_array: (a: number, b: number) => void;
  readonly float32data_to_typed_array: (a: number, b: number) => void;
  readonly float64data_to_typed_array: (a: number, b: number) => void;
  readonly __wbg_ffitable_free: (a: number) => void;
  readonly ffitable_numBatches: (a: number) => number;
  readonly ffitable_schemaAddr: (a: number) => number;
  readonly ffitable_arrayAddr: (a: number, b: number) => number;
  readonly ffitable_arrayAddrs: (a: number, b: number) => void;
  readonly ffitable_drop: (a: number) => void;
  readonly __wbg_table_free: (a: number) => void;
  readonly table_schema: (a: number) => number;
  readonly table_recordBatch: (a: number, b: number) => number;
  readonly table_toFFI: (a: number, b: number) => void;
  readonly table_intoFFI: (a: number, b: number) => void;
  readonly table_intoIPCStream: (a: number, b: number) => void;
  readonly table_fromIPCStream: (a: number, b: number, c: number) => void;
  readonly table_get_array_memory_size: (a: number) => number;
  readonly table_numBatches: (a: number) => number;
  readonly __wbg_ffirecordbatch_free: (a: number) => void;
  readonly ffirecordbatch_arrayAddr: (a: number) => number;
  readonly ffirecordbatch_schemaAddr: (a: number) => number;
  readonly __wbg_recordbatch_free: (a: number) => void;
  readonly recordbatch_numRows: (a: number) => number;
  readonly recordbatch_numColumns: (a: number) => number;
  readonly recordbatch_schema: (a: number) => number;
  readonly recordbatch_toFFI: (a: number, b: number) => void;
  readonly recordbatch_intoFFI: (a: number, b: number) => void;
  readonly recordbatch_intoIPCStream: (a: number, b: number) => void;
  readonly recordbatch_with_schema: (a: number, b: number, c: number) => void;
  readonly recordbatch_slice: (a: number, b: number, c: number) => number;
  readonly recordbatch_get_array_memory_size: (a: number) => number;
  readonly __wbg_schema_free: (a: number) => void;
  readonly schema_to_ffi: (a: number, b: number) => void;
  readonly schema_field: (a: number, b: number) => number;
  readonly schema_field_with_name: (a: number, b: number, c: number, d: number) => void;
  readonly schema_with_metadata: (a: number, b: number, c: number) => void;
  readonly schema_index_of: (a: number, b: number, c: number, d: number) => void;
  readonly schema_metadata: (a: number, b: number) => void;
  readonly wasmMemory: () => number;
  readonly _functionTable: () => number;
  readonly __wbg_ffiarrowarray_free: (a: number) => void;
  readonly ffiarrowarray_addr: (a: number) => number;
  readonly __wbg_ffiarrowschema_free: (a: number) => void;
  readonly __wbg_field_free: (a: number) => void;
  readonly field_to_ffi: (a: number, b: number) => void;
  readonly field_name: (a: number, b: number) => void;
  readonly field_with_name: (a: number, b: number, c: number, d: number) => void;
  readonly field_data_type: (a: number) => number;
  readonly field_is_nullable: (a: number) => number;
  readonly field_metadata: (a: number, b: number) => void;
  readonly field_with_metadata: (a: number, b: number, c: number) => void;
  readonly ffiarrowschema_addr: (a: number) => number;
  readonly rust_zstd_wasm_shim_malloc: (a: number) => number;
  readonly rust_zstd_wasm_shim_calloc: (a: number, b: number) => number;
  readonly rust_zstd_wasm_shim_free: (a: number) => void;
  readonly rust_zstd_wasm_shim_memcpy: (a: number, b: number, c: number) => number;
  readonly rust_zstd_wasm_shim_memmove: (a: number, b: number, c: number) => number;
  readonly rust_zstd_wasm_shim_memset: (a: number, b: number, c: number) => number;
  readonly BrotliDecoderCreateInstance: (a: number, b: number, c: number) => number;
  readonly BrotliDecoderSetParameter: (a: number, b: number, c: number) => void;
  readonly BrotliDecoderDecompressPrealloc: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number, j: number, k: number) => void;
  readonly BrotliDecoderDecompressWithReturnInfo: (a: number, b: number, c: number, d: number, e: number) => void;
  readonly BrotliDecoderDecompress: (a: number, b: number, c: number, d: number) => number;
  readonly BrotliDecoderDecompressStream: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly BrotliDecoderDecompressStreaming: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly BrotliDecoderMallocU8: (a: number, b: number) => number;
  readonly BrotliDecoderFreeU8: (a: number, b: number, c: number) => void;
  readonly BrotliDecoderMallocUsize: (a: number, b: number) => number;
  readonly BrotliDecoderFreeUsize: (a: number, b: number, c: number) => void;
  readonly BrotliDecoderDestroyInstance: (a: number) => void;
  readonly BrotliDecoderHasMoreOutput: (a: number) => number;
  readonly BrotliDecoderTakeOutput: (a: number, b: number) => number;
  readonly BrotliDecoderIsUsed: (a: number) => number;
  readonly BrotliDecoderIsFinished: (a: number) => number;
  readonly BrotliDecoderGetErrorCode: (a: number) => number;
  readonly BrotliDecoderGetErrorString: (a: number) => number;
  readonly BrotliDecoderErrorString: (a: number) => number;
  readonly BrotliDecoderVersion: () => number;
  readonly __wbindgen_malloc: (a: number, b: number) => number;
  readonly __wbindgen_realloc: (a: number, b: number, c: number, d: number) => number;
  readonly __wbindgen_export_2: WebAssembly.Table;
  readonly wasm_bindgen__convert__closures__invoke1_mut__h0cc9e15bb89b7894: (a: number, b: number, c: number) => void;
  readonly __wbindgen_add_to_stack_pointer: (a: number) => number;
  readonly __wbindgen_free: (a: number, b: number, c: number) => void;
  readonly __wbindgen_exn_store: (a: number) => void;
  readonly wasm_bindgen__convert__closures__invoke2_mut__h8731869315809749: (a: number, b: number, c: number, d: number) => void;
}

export type SyncInitInput = BufferSource | WebAssembly.Module;
/**
* Instantiates the given `module`, which can either be bytes or
* a precompiled `WebAssembly.Module`.
*
* @param {SyncInitInput} module
*
* @returns {InitOutput}
*/
export function initSync(module: SyncInitInput): InitOutput;

/**
* If `module_or_path` is {RequestInfo} or {URL}, makes a request and
* for everything else, calls `WebAssembly.instantiate` directly.
*
* @param {InitInput | Promise<InitInput>} module_or_path
*
* @returns {Promise<InitOutput>}
*/
export default function __wbg_init (module_or_path?: InitInput | Promise<InitInput>): Promise<InitOutput>;
